==================
SQL in F(unctions)
==================


.. image:: https://img.shields.io/pypi/v/sqlf.svg
        :target: https://pypi.python.org/pypi/sqlf

.. image:: https://img.shields.io/travis/digitalmensch/sqlf.svg
        :target: https://travis-ci.org/digitalmensch/sqlf

.. image:: https://readthedocs.org/projects/sqlf/badge/?version=latest
        :target: https://sqlf.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/digitalmensch/sqlf/shield.svg
     :target: https://pyup.io/repos/github/digitalmensch/sqlf/
     :alt: Updates

.. image:: https://snyk.io/test/github/digitalmensch/sqlf/badge.svg
     :target: https://snyk.io/test/github/digitalmensch/sqlf
     :alt: Snyk

.. image:: https://api.codacy.com/project/badge/Grade/391c7b2d4f0143cf9edf62f7c0ec38c0
     :target: https://www.codacy.com/app/betabrain/sqlf



SQL in Python __doc__-strings as an alternative to ORMs


* Free software: MIT license
* Documentation: https://sqlf.readthedocs.io.


Features
--------

* Access to in-memory and/or file-backed databases (Sqlite3)
* Lightweight, ORM-less abstraction
* Support for Sqlite3's UDFs (user-defined functions)
* Convenient library of UDFs


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
